@@ -11,7 +11,7 @@ step "Install repositories on target machines..." do
   repo_configs_dir = 'repo-configs'
 
   hosts.each do |host|
-    install_repos_on(host, sha, repo_configs_dir)
+    install_repos_on(host, 'facter', sha, repo_configs_dir)
   end
 end
 
